/* $Header: /cvs/gnome/gIDE/src/gI_menus.h,v 1.6 2000/02/21 19:55:37 jpr Exp $ */
/* gIDE
 * Copyright (C) 1998-2000 Steffen Kern
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GI_MENUS_H
#define GI_MENUS_H

#include <gnome.h>
#include "gI_window.h"

/*
 * Prototypes for 'gI_menus.c'
 */
void gI_menus_create_menubar( GideWindow *window );

void gI_menus_set_sensitive( GideWindow *window, gchar *path, gint sensitive );
void gI_menus_set_sensitive_default( GideWindow *window  );
void gI_menus_set_sensitive_readonly( GideWindow *window, gboolean state );
void gI_menus_set_sensitive_debugon( GideWindow *window );
void gI_menus_set_sensitive_debugoff( GideWindow *window );

void gI_menus_add_item_widget( GideWindow *window, gchar *path,
			       GtkWidget *widget);
void gI_menus_remove_item_widget( GideWindow *window, gchar *path );
GtkWidget* gI_menus_get_item_widget( GideWindow *window, gchar *path );

void gI_menus_free_items( GideWindow *window );

#endif

